@@ -565,9 +565,9 @@ int32_t main(int32_t command_args_length, const char *command_args[]) {
 
   // Binary mode in all systems
 #ifdef _WIN32
-  _setmode(stdout, _O_BINARY);
-  _setmode(stderr, _O_BINARY);
-  _setmode(stdin, _O_BINARY);
+  _setmode(fileno(stdout), _O_BINARY);
+  _setmode(fileno(stderr), _O_BINARY);
+  _setmode(fileno(stdin), _O_BINARY);
 #endif
   
   SPVM_ENV* env = SPVM_NATIVE_new_env_prepared();
