@@ -438,45 +438,43 @@ enum {
   SPVM_OPCODE_C_ID_TYPE_CONVERSION_LONG_OBJECT_TO_LONG,
   SPVM_OPCODE_C_ID_TYPE_CONVERSION_FLOAT_OBJECT_TO_FLOAT,
   SPVM_OPCODE_C_ID_TYPE_CONVERSION_DOUBLE_OBJECT_TO_DOUBLE,
-  SPVM_OPCODE_C_ID_PUSH_ARG_BYTE,
-  SPVM_OPCODE_C_ID_PUSH_ARG_SHORT,
-  SPVM_OPCODE_C_ID_PUSH_ARG_INT,
-  SPVM_OPCODE_C_ID_PUSH_ARG_LONG,
-  SPVM_OPCODE_C_ID_PUSH_ARG_FLOAT,
-  SPVM_OPCODE_C_ID_PUSH_ARG_DOUBLE,
-  SPVM_OPCODE_C_ID_PUSH_ARG_OBJECT,
-  SPVM_OPCODE_C_ID_PUSH_ARG_REF,
-  SPVM_OPCODE_C_ID_PUSH_ARG_UNDEF,
-  SPVM_OPCODE_C_ID_PUSH_ARG_MULNUM_BYTE,
-  SPVM_OPCODE_C_ID_PUSH_ARG_MULNUM_SHORT,
-  SPVM_OPCODE_C_ID_PUSH_ARG_MULNUM_INT,
-  SPVM_OPCODE_C_ID_PUSH_ARG_MULNUM_LONG,
-  SPVM_OPCODE_C_ID_PUSH_ARG_MULNUM_FLOAT,
-  SPVM_OPCODE_C_ID_PUSH_ARG_MULNUM_DOUBLE,
-  SPVM_OPCODE_C_ID_CALL_CLASS_METHOD_BY_ID,
-  SPVM_OPCODE_C_ID_CALL_INSTANCE_METHOD_BY_ID,
-  SPVM_OPCODE_C_ID_CALL_INSTANCE_METHOD_BY_NAME,
-  SPVM_OPCODE_C_ID_GET_ARG_BYTE,
-  SPVM_OPCODE_C_ID_GET_ARG_SHORT,
-  SPVM_OPCODE_C_ID_GET_ARG_INT,
-  SPVM_OPCODE_C_ID_GET_ARG_LONG,
-  SPVM_OPCODE_C_ID_GET_ARG_FLOAT,
-  SPVM_OPCODE_C_ID_GET_ARG_DOUBLE,
-  SPVM_OPCODE_C_ID_GET_ARG_OBJECT,
-  SPVM_OPCODE_C_ID_GET_ARG_REF,
-  SPVM_OPCODE_C_ID_GET_ARG_MULNUM_BYTE,
-  SPVM_OPCODE_C_ID_GET_ARG_MULNUM_SHORT,
-  SPVM_OPCODE_C_ID_GET_ARG_MULNUM_INT,
-  SPVM_OPCODE_C_ID_GET_ARG_MULNUM_LONG,
-  SPVM_OPCODE_C_ID_GET_ARG_MULNUM_FLOAT,
-  SPVM_OPCODE_C_ID_GET_ARG_MULNUM_DOUBLE,
-  SPVM_OPCODE_C_ID_GET_ARG_OPTIONAL_BYTE,
-  SPVM_OPCODE_C_ID_GET_ARG_OPTIONAL_SHORT,
-  SPVM_OPCODE_C_ID_GET_ARG_OPTIONAL_INT,
-  SPVM_OPCODE_C_ID_GET_ARG_OPTIONAL_LONG,
-  SPVM_OPCODE_C_ID_GET_ARG_OPTIONAL_FLOAT,
-  SPVM_OPCODE_C_ID_GET_ARG_OPTIONAL_DOUBLE,
-  SPVM_OPCODE_C_ID_GET_ARG_OPTIONAL_OBJECT,
+  SPVM_OPCODE_C_ID_SET_STACK_BYTE,
+  SPVM_OPCODE_C_ID_SET_STACK_SHORT,
+  SPVM_OPCODE_C_ID_SET_STACK_INT,
+  SPVM_OPCODE_C_ID_SET_STACK_LONG,
+  SPVM_OPCODE_C_ID_SET_STACK_FLOAT,
+  SPVM_OPCODE_C_ID_SET_STACK_DOUBLE,
+  SPVM_OPCODE_C_ID_SET_STACK_OBJECT,
+  SPVM_OPCODE_C_ID_SET_STACK_REF,
+  SPVM_OPCODE_C_ID_SET_STACK_UNDEF,
+  SPVM_OPCODE_C_ID_SET_STACK_MULNUM_BYTE,
+  SPVM_OPCODE_C_ID_SET_STACK_MULNUM_SHORT,
+  SPVM_OPCODE_C_ID_SET_STACK_MULNUM_INT,
+  SPVM_OPCODE_C_ID_SET_STACK_MULNUM_LONG,
+  SPVM_OPCODE_C_ID_SET_STACK_MULNUM_FLOAT,
+  SPVM_OPCODE_C_ID_SET_STACK_MULNUM_DOUBLE,
+  SPVM_OPCODE_C_ID_CALL_METHOD,
+  SPVM_OPCODE_C_ID_GET_STACK_BYTE,
+  SPVM_OPCODE_C_ID_GET_STACK_SHORT,
+  SPVM_OPCODE_C_ID_GET_STACK_INT,
+  SPVM_OPCODE_C_ID_GET_STACK_LONG,
+  SPVM_OPCODE_C_ID_GET_STACK_FLOAT,
+  SPVM_OPCODE_C_ID_GET_STACK_DOUBLE,
+  SPVM_OPCODE_C_ID_GET_STACK_OBJECT,
+  SPVM_OPCODE_C_ID_GET_STACK_REF,
+  SPVM_OPCODE_C_ID_GET_STACK_MULNUM_BYTE,
+  SPVM_OPCODE_C_ID_GET_STACK_MULNUM_SHORT,
+  SPVM_OPCODE_C_ID_GET_STACK_MULNUM_INT,
+  SPVM_OPCODE_C_ID_GET_STACK_MULNUM_LONG,
+  SPVM_OPCODE_C_ID_GET_STACK_MULNUM_FLOAT,
+  SPVM_OPCODE_C_ID_GET_STACK_MULNUM_DOUBLE,
+  SPVM_OPCODE_C_ID_GET_STACK_OPTIONAL_BYTE,
+  SPVM_OPCODE_C_ID_GET_STACK_OPTIONAL_SHORT,
+  SPVM_OPCODE_C_ID_GET_STACK_OPTIONAL_INT,
+  SPVM_OPCODE_C_ID_GET_STACK_OPTIONAL_LONG,
+  SPVM_OPCODE_C_ID_GET_STACK_OPTIONAL_FLOAT,
+  SPVM_OPCODE_C_ID_GET_STACK_OPTIONAL_DOUBLE,
+  SPVM_OPCODE_C_ID_GET_STACK_OPTIONAL_OBJECT,
   SPVM_OPCODE_C_ID_RETURN_VOID,
   SPVM_OPCODE_C_ID_RETURN_BYTE,
   SPVM_OPCODE_C_ID_RETURN_SHORT,
