@@ -438,45 +438,43 @@ const char* const* SPVM_OPCODE_C_ID_NAMES(void) {
     "TYPE_CONVERSION_LONG_OBJECT_TO_LONG",
     "TYPE_CONVERSION_FLOAT_OBJECT_TO_FLOAT",
     "TYPE_CONVERSION_DOUBLE_OBJECT_TO_DOUBLE",
-    "PUSH_ARG_BYTE",
-    "PUSH_ARG_SHORT",
-    "PUSH_ARG_INT",
-    "PUSH_ARG_LONG",
-    "PUSH_ARG_FLOAT",
-    "PUSH_ARG_DOUBLE",
-    "PUSH_ARG_OBJECT",
-    "PUSH_ARG_REF",
-    "PUSH_ARG_UNDEF",
-    "PUSH_ARG_MULNUM_BYTE",
-    "PUSH_ARG_MULNUM_SHORT",
-    "PUSH_ARG_MULNUM_INT",
-    "PUSH_ARG_MULNUM_LONG",
-    "PUSH_ARG_MULNUM_FLOAT",
-    "PUSH_ARG_MULNUM_DOUBLE",
-    "CALL_CLASS_METHOD_BY_ID",
-    "CALL_INSTANCE_METHOD_BY_ID",
-    "CALL_INSTANCE_METHOD_BY_NAME",
-    "GET_ARG_BYTE",
-    "GET_ARG_SHORT",
-    "GET_ARG_INT",
-    "GET_ARG_LONG",
-    "GET_ARG_FLOAT",
-    "GET_ARG_DOUBLE",
-    "GET_ARG_OBJECT",
-    "GET_ARG_REF",
-    "GET_ARG_MULNUM_BYTE",
-    "GET_ARG_MULNUM_SHORT",
-    "GET_ARG_MULNUM_INT",
-    "GET_ARG_MULNUM_LONG",
-    "GET_ARG_MULNUM_FLOAT",
-    "GET_ARG_MULNUM_DOUBLE",
-    "GET_ARG_OPTIONAL_BYTE",
-    "GET_ARG_OPTIONAL_SHORT",
-    "GET_ARG_OPTIONAL_INT",
-    "GET_ARG_OPTIONAL_LONG",
-    "GET_ARG_OPTIONAL_FLOAT",
-    "GET_ARG_OPTIONAL_DOUBLE",
-    "GET_ARG_OPTIONAL_OBJECT",
+    "SET_STACK_BYTE",
+    "SET_STACK_SHORT",
+    "SET_STACK_INT",
+    "SET_STACK_LONG",
+    "SET_STACK_FLOAT",
+    "SET_STACK_DOUBLE",
+    "SET_STACK_OBJECT",
+    "SET_STACK_REF",
+    "SET_STACK_UNDEF",
+    "SET_STACK_MULNUM_BYTE",
+    "SET_STACK_MULNUM_SHORT",
+    "SET_STACK_MULNUM_INT",
+    "SET_STACK_MULNUM_LONG",
+    "SET_STACK_MULNUM_FLOAT",
+    "SET_STACK_MULNUM_DOUBLE",
+    "CALL_METHOD",
+    "GET_STACK_BYTE",
+    "GET_STACK_SHORT",
+    "GET_STACK_INT",
+    "GET_STACK_LONG",
+    "GET_STACK_FLOAT",
+    "GET_STACK_DOUBLE",
+    "GET_STACK_OBJECT",
+    "GET_STACK_REF",
+    "GET_STACK_MULNUM_BYTE",
+    "GET_STACK_MULNUM_SHORT",
+    "GET_STACK_MULNUM_INT",
+    "GET_STACK_MULNUM_LONG",
+    "GET_STACK_MULNUM_FLOAT",
+    "GET_STACK_MULNUM_DOUBLE",
+    "GET_STACK_OPTIONAL_BYTE",
+    "GET_STACK_OPTIONAL_SHORT",
+    "GET_STACK_OPTIONAL_INT",
+    "GET_STACK_OPTIONAL_LONG",
+    "GET_STACK_OPTIONAL_FLOAT",
+    "GET_STACK_OPTIONAL_DOUBLE",
+    "GET_STACK_OPTIONAL_OBJECT",
     "RETURN_VOID",
     "RETURN_BYTE",
     "RETURN_SHORT",
